import requests, py2b


class player():

    def __init__(self, username):
        self.username = username

    def info(self):
        self.request = requests.request("GET", f"https://api.2b2t.dev/stats?username={self.username}")
        return self.request.json()

    def lastSeen(self):
        self.request = requests.request("GET", f"https://api.2b2t.dev/seen?username={self.username}")
        return self.request.json()
    
    def lastDeath(self):
        self.request = requests.request("GET", f"https://api.2b2t.dev/stats?lastdeath={self.username}")
        return self.request.json()

    def lastKill(self):
        self.request = requests.request("GET", f"https://api.2b2t.dev/stats?lastkill={self.username}")
        return self.request.json()

    def prioBanned(self):
        return py2b.check(self.username)
        



import requests




def serverStatus():
    request = requests.request("GET", "https://api.2b2t.dev/status")
    return request.json()

def prioqLength():
    request = requests.request("GET", "https://api.2b2t.dev/prioq")
    return request.json()


import requests
from colorama import Fore, init
import threading

class listCheck():

    def __init__(self, usernames, printOut=False):
        self.usernames = usernames
        
        self.printOut = printOut
        init(convert=True)
        
        
    def listBased(self, usernameList):
        for username in usernameList:
            self.check(username)

    def check(self, username):    
        data = f'ign={username}'
        headers = {
            'Content-Type': 'application/x-www-form-urlencoded'
            }

        request = requests.request('POST', "https://donate.2b2t.org/category/738999", data=data, headers=headers)
        if self.printOut:
            if 'rate limited' in request.text:
                print(Fore.LIGHTMAGENTA_EX + f"YOU'VE BEEN RATELIMITED!! :(")
            elif 'not a valid' in request.text:
                print(Fore.LIGHTRED_EX + f"{username} is not a valid username")
            elif 'Unable' in request.text:
                print(Fore.LIGHTRED_EX + f"Unable to find a player with the username: {input}")
            elif 'banned' not in request.text:
                print(Fore.LIGHTRED_EX + f"{username} is not currently banned")
            else:
                print(Fore.LIGHTGREEN_EX + f"{username} is currently banned")
        else:
            if 'rate limited' in request.text:
                return 0
            elif 'not a valid' in request.text:
                return 1
            elif 'Unable' in request.text:
                return 2
            elif 'banned' not in request.text:
                return False
            else:
                return True

    def l1(self):
        for i in range(len(self.lines1)):
            self.check(self.lines1[i])
    def l2(self):
        for i in range(len(self.lines2)):
            self.check(self.lines2[i])

    def start(self):
        if self.usernames is list:
            self.listBased(self.usernames)

        else:
            self.lines = [item.replace("\n", "") for item in open(self.usernames, 'r').readlines()]
            self.lines1 = self.lines[:len(self.lines)//2]
            self.lines2 = self.lines[len(self.lines)//2:]
            self.threads = []
            self.t1 = threading.Thread(target=self.l1)
            self.t2 = threading.Thread(target=self.l2)
            self.threads.append(self.t1)
            self.threads.append(self.t2)
            self.t1.start()
            self.t2.start()

        print(('\nFinished loading all threads.\n').center(119))
        for x in self.threads:
            x.join()

        input(Fore.RESET + 'Finished Checking!')



from py2b import __author__, __version__
import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='2b2t.py',
    version=__version__,
    author=__author__,
    description='A package for all things 2b2t',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/BGP0/2b2t.py',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6'
)


import requests
from colorama import Fore, init
import threading

def check(username, printOut=False):
    data = f'ign={username}'
    headers = {
        'Content-Type': 'application/x-www-form-urlencoded'
        }

    request = requests.request('POST', "https://donate.2b2t.org/category/738999", data=data, headers=headers)
    if not printOut:
        if 'rate limited' in request.text:
            return 0
        elif 'not a valid' in request.text:
            return 1
        elif 'Unable' in request.text:
            return 2
        elif 'banned' not in request.text:
            return False
        else:
            return True
    else:
        if 'rate limited' in request.text:
            print(Fore.LIGHTMAGENTA_EX + f"YOU'VE BEEN RATELIMITED!! :(")
        elif 'not a valid' in request.text:
            print(Fore.LIGHTRED_EX + f"{username} is not a valid username")
        elif 'Unable' in request.text:
            print(Fore.LIGHTRED_EX + f"Unable to find a player with the username: {username}")
        elif 'banned' not in request.text:
            print(Fore.LIGHTRED_EX + f"{username} is not currently banned")
        else:
            print(Fore.LIGHTGREEN_EX + f"{username} is currently banned")

